@@ -127,22 +127,22 @@ func createSchedulerConfigMap(ctx context.Context, kclient *k8sclient.Clientset)
 
 func waitForConfigMapUpdate(ctx context.Context, kclient *k8sclient.Clientset) error {
 	return wait.PollImmediate(1*time.Second, 5*time.Minute, func() (bool, error) {
-		configMap, err := kclient.CoreV1().ConfigMaps("openshift-kube-scheduler").Get(ctx, "config", metav1.GetOptions{})
+		configMap, err := kclient.CoreV1().ConfigMaps("openshift-kube-scheduler").Get(ctx, "policy-configmap", metav1.GetOptions{})
 		if err != nil {
 			klog.Infof("error waiting for config map to exist: %v\n", err)
 			return false, nil
 		}
 		klog.Infof("Found configmap")
 		// We should have algorithmSource as key in our map which shows we have configured policy.
-		if data, ok := configMap.Data["config.yaml"]; !ok {
+		if data, ok := configMap.Data["policy.cfg"]; !ok {
 			klog.Info("Still waiting for configmap created with my policy")
 			return false, nil
 		} else {
-			if strings.Contains(data, "policy-configmap") {
-				klog.Info("Configmap created with required policy name")
+			if strings.Contains(data, "predicates") {
+				klog.Info("Configmap created")
 				return true, nil
 			} else {
-				klog.Info("Still waiting for configmap to be created with my policy-configmap")
+				klog.Info("Still waiting for configmap to be created")
 			}
 		}
 		klog.Infof("configmap %v is not yet available", configMap.Name)
@@ -303,7 +303,7 @@ func TestMetricsAccessible(t *testing.T) {
 		t.Fatalf("error creating route client for prometheus: %v", err)
 	}
 	var response model.Value
-	err = wait.PollImmediate(time.Second*1, time.Second*30, func() (bool, error) {
+	err = wait.PollImmediate(time.Second*1, time.Minute*3, func() (bool, error) {
 		response, _, err = prometheusClient.Query(ctx, `scheduler_scheduling_duration_seconds_sum`, time.Now())
 		if err != nil {
 			return false, fmt.Errorf("error querying prometheus: %v", err)
